@@ -25,12 +25,13 @@
 
 #include "fuse_common.h"
 
-#include <utime.h>
 #include <fcntl.h>
-#include <sys/types.h>
+#include <stdint.h>
 #include <sys/stat.h>
 #include <sys/statvfs.h>
+#include <sys/types.h>
 #include <sys/uio.h>
+#include <utime.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -44,7 +45,7 @@ extern "C" {
 #define FUSE_ROOT_ID 1
 
 /** Inode number type */
-typedef unsigned long fuse_ino_t;
+typedef uint64_t fuse_ino_t;
 
 /** Request pointer type */
 typedef struct fuse_req *fuse_req_t;
@@ -88,7 +89,8 @@ struct fuse_entry_param {
 	 * it as an error.
 	 *
 	 */
-	unsigned long generation;
+        uint64_t generation;
+
 
 	/** Inode attributes.
 	 *
@@ -122,20 +124,10 @@ struct fuse_ctx {
 };
 
 struct fuse_forget_data {
-	uint64_t ino;
+	fuse_ino_t ino;
 	uint64_t nlookup;
 };
 
-/* 'to_set' flags in setattr */
-#define FUSE_SET_ATTR_MODE	(1 << 0)
-#define FUSE_SET_ATTR_UID	(1 << 1)
-#define FUSE_SET_ATTR_GID	(1 << 2)
-#define FUSE_SET_ATTR_SIZE	(1 << 3)
-#define FUSE_SET_ATTR_ATIME	(1 << 4)
-#define FUSE_SET_ATTR_MTIME	(1 << 5)
-#define FUSE_SET_ATTR_ATIME_NOW	(1 << 7)
-#define FUSE_SET_ATTR_MTIME_NOW	(1 << 8)
-
 /* ----------------------------------------------------------- *
  * Request methods and replies				       *
  * ----------------------------------------------------------- */
@@ -233,7 +225,7 @@ struct fuse_lowlevel_ops {
 	 * @param ino the inode number
 	 * @param nlookup the number of lookups to forget
 	 */
-	void (*forget) (fuse_req_t req, fuse_ino_t ino, unsigned long nlookup);
+	void (*forget) (fuse_req_t req, fuse_ino_t ino, uint64_t nlookup);
 
 	/**
 	 * Get file attributes
