@@ -25,17 +25,20 @@ using std::string;
 using std::vector;
 
 int
-Policy::Func::eprand(const Category::Enum::Type  type,
+Policy::Func::eprand(const Category::Enum::Type  type_,
                      const Branches             &branches_,
-                     const char                 *fusepath,
-                     const uint64_t              minfreespace,
-                     vector<const string*>      &paths)
+                     const char                 *fusepath_,
+                     const uint64_t              minfreespace_,
+                     vector<const string*>      &paths_)
 {
   int rv;
 
-  rv = Policy::Func::epall(type,branches_,fusepath,minfreespace,paths);
+  rv = Policy::Func::epall(type_,branches_,fusepath_,minfreespace_,paths_);
   if(rv == 0)
-    std::random_shuffle(paths.begin(),paths.end());
+    {
+      std::random_shuffle(paths_.begin(),paths_.end());
+      paths_.resize(1);
+    }
 
   return rv;
 }
